# amconll
AMCONLL file and class utilities for using, reading and writing AM-dependency annotated sentences


## Installation

```
pip install amconll
```

Or, if you prefer,

```
python -m pip install amconll
```

The method `reorder_amconll` requires the penman library, which you can install with

```
pip install penman
```